==> packages-20.1-OpenSSL-amd64.tar: usr/local/opnsense/mvc/app/controllers/OPNsense/Freeradius/Api/DhcpController.php <==
<?php

/**
 *    Copyright (C) 2015 - 2017 Deciso B.V.
 *    Copyright (C) 2019 Michael Muenz <m.muenz@gmail.com>
 *
 *    All rights reserved.
 *
 *    Redistribution and use in source and binary forms, with or without
 *    modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *    POSSIBILITY OF SUCH DAMAGE.
 *
 */

namespace OPNsense\Freeradius\Api;

use \OPNsense\Base\ApiMutableModelControllerBase;

class DhcpController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'dhcp';
    protected static $internalModelClass = '\OPNsense\Freeradius\Dhcp';

    public function searchDhcpAction()
    {
        return $this->searchBase('dhcps.dhcp', array("enabled", "dns", "netmask", "gatewayip"));
    }
    public function getDhcpAction($uuid = null)
    {
        $this->sessionClose();
        return $this->getBase('dhcp', 'dhcps.dhcp', $uuid);
    }
    public function addDhcpAction()
    {
        return $this->addBase('dhcp', 'dhcps.dhcp');
    }
    public function delDhcpAction($uuid)
    {
        return $this->delBase('dhcps.dhcp', $uuid);
    }
    public function setDhcpAction($uuid)
    {
        return $this->setBase('dhcp', 'dhcps.dhcp', $uuid);
    }
    public function toggleDhcpAction($uuid)
    {
        return $this->toggleBase('dhcps.dhcp', $uuid);
    }
}

==> packages-20.7-OpenSSL-amd64.tar: usr/local/opnsense/mvc/app/controllers/OPNsense/Freeradius/Api/DhcpController.php <==
<?php

/**
 *    Copyright (C) 2015 - 2017 Deciso B.V.
 *    Copyright (C) 2019 Michael Muenz <m.muenz@gmail.com>
 *
 *    All rights reserved.
 *
 *    Redistribution and use in source and binary forms, with or without
 *    modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *    POSSIBILITY OF SUCH DAMAGE.
 *
 */

namespace OPNsense\Freeradius\Api;

use OPNsense\Base\ApiMutableModelControllerBase;

class DhcpController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'dhcp';
    protected static $internalModelClass = '\OPNsense\Freeradius\Dhcp';

    public function searchDhcpAction()
    {
        return $this->searchBase('dhcps.dhcp', array("enabled", "dns", "netmask", "gatewayip"));
    }
    public function getDhcpAction($uuid = null)
    {
        $this->sessionClose();
        return $this->getBase('dhcp', 'dhcps.dhcp', $uuid);
    }
    public function addDhcpAction()
    {
        return $this->addBase('dhcp', 'dhcps.dhcp');
    }
    public function delDhcpAction($uuid)
    {
        return $this->delBase('dhcps.dhcp', $uuid);
    }
    public function setDhcpAction($uuid)
    {
        return $this->setBase('dhcp', 'dhcps.dhcp', $uuid);
    }
    public function toggleDhcpAction($uuid)
    {
        return $this->toggleBase('dhcps.dhcp', $uuid);
    }
}
